==> igniteui-react-layouts-18.0.0.tgz: package/esm2015/lib/igr-tool-action-performed-event-args.js <==
import { IgrToolActionEventDetail } from "./igr-tool-action-event-detail";
import { IgrToolActionEventDetailCollection } from "./igr-tool-action-event-detail-collection";
import { ToolActionPerformedEventArgs as ToolActionPerformedEventArgs_internal } from "./ToolActionPerformedEventArgs";
import { ensureBool } from "igniteui-react-core";
import { ToolActionEventDetailCollection as ToolActionEventDetailCollection_internal } from "./ToolActionEventDetailCollection";
import { ToolActionEventDetail } from "./ToolActionEventDetail";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
export class IgrToolActionPerformedEventArgs {
    constructor() {
        this._detailCollection = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new ToolActionPerformedEventArgs_internal();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    get isAggregate() {
        return this.i.c;
    }
    set isAggregate(v) {
        this.i.c = ensureBool(v);
    }
    get detail() {
        if (this.i.a == null) {
            return null;
        }
        if (!this.i.a.externalObject) {
            let e = new IgrToolActionEventDetail();
            e._implementation = this.i.a;
            this.i.a.externalObject = e;
        }
        return this.i.a.externalObject;
    }
    set detail(v) {
        v == null ? this.i.a = null : this.i.a = v.i;
    }
    get detailCollection() {
        if (this._detailCollection === null) {
            let coll = new IgrToolActionEventDetailCollection();
            let innerColl = this.i.b;
            if (!innerColl) {
                innerColl = new ToolActionEventDetailCollection_internal();
            }
            this._detailCollection = coll._fromInner(innerColl);
            this.i.b = innerColl;
        }
        return this._detailCollection;
    }
    set detailCollection(v) {
        if (this._detailCollection !== null) {
            this._detailCollection._setSyncTarget(null);
            this._detailCollection = null;
        }
        let coll = new IgrToolActionEventDetailCollection();
        this._detailCollection = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(ToolActionEventDetail.$type);
        let innerColl = this.i.b;
        if (!innerColl) {
            innerColl = new ToolActionEventDetailCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._detailCollection._setSyncTarget(syncColl);
        this.i.b = innerColl;
    }
}

==> igniteui-react-layouts-18.1.0.tgz: package/esm2015/lib/igr-tool-action-performed-event-args.js <==
import { IgrToolActionEventDetail } from "./igr-tool-action-event-detail";
import { IgrToolActionEventDetailCollection } from "./igr-tool-action-event-detail-collection";
import { ToolActionPerformedEventArgs as ToolActionPerformedEventArgs_internal } from "./ToolActionPerformedEventArgs";
import { ensureBool } from "igniteui-react-core";
import { ToolActionEventDetailCollection as ToolActionEventDetailCollection_internal } from "./ToolActionEventDetailCollection";
import { ToolActionEventDetail } from "./ToolActionEventDetail";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
export class IgrToolActionPerformedEventArgs {
    constructor() {
        this._detailCollection = null;
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new ToolActionPerformedEventArgs_internal();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    get isAggregate() {
        return this.i.c;
    }
    set isAggregate(v) {
        this.i.c = ensureBool(v);
    }
    get detail() {
        const r = this.i.a;
        if (r == null) {
            return null;
        }
        if (!r.externalObject) {
            let e = new IgrToolActionEventDetail();
            if (e.i.setNativeElement) {
                e.i.setNativeElement(r);
            }
            else {
                e._implementation = r;
            }
            r.externalObject = e;
        }
        return r.externalObject;
    }
    set detail(v) {
        v == null ? this.i.a = null : this.i.a = v.i;
    }
    get detailCollection() {
        if (this._detailCollection === null) {
            let coll = new IgrToolActionEventDetailCollection();
            let innerColl = this.i.b;
            if (!innerColl) {
                innerColl = new ToolActionEventDetailCollection_internal();
            }
            this._detailCollection = coll._fromInner(innerColl);
            this.i.b = innerColl;
        }
        return this._detailCollection;
    }
    set detailCollection(v) {
        if (this._detailCollection !== null) {
            this._detailCollection._setSyncTarget(null);
            this._detailCollection = null;
        }
        let coll = new IgrToolActionEventDetailCollection();
        this._detailCollection = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(ToolActionEventDetail.$type);
        let innerColl = this.i.b;
        if (!innerColl) {
            innerColl = new ToolActionEventDetailCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._detailCollection._setSyncTarget(syncColl);
        this.i.b = innerColl;
    }
}
